summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qpopupmenu_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qpopupmenu_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qpopupmenu_imp.cpp96
1 files changed, 48 insertions, 48 deletions
diff --git a/kjsembed/qtbindings/qpopupmenu_imp.cpp b/kjsembed/qtbindings/qpopupmenu_imp.cpp
index 7b652422..f11c9a3b 100644
--- a/kjsembed/qtbindings/qpopupmenu_imp.cpp
+++ b/kjsembed/qtbindings/qpopupmenu_imp.cpp
@@ -23,19 +23,19 @@
*/
namespace KJSEmbed {
-QPopupMenuImp::QPopupMenuImp( KJS::ExecState *exec, int mid, bool constructor )
+TTQPopupMenuImp::TQPopupMenuImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-QPopupMenuImp::~QPopupMenuImp()
+TTQPopupMenuImp::~TQPopupMenuImp()
{
}
/**
* Adds bindings for static methods and enum constants to the specified Object.
*/
-void QPopupMenuImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQPopupMenuImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -43,11 +43,11 @@ void QPopupMenuImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QPopupMenuImp *meth = new QPopupMenuImp( exec, methods[idx].id );
+ TQPopupMenuImp *meth = new TQPopupMenuImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -60,7 +60,7 @@ void QPopupMenuImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object
/**
* Adds bindings for instance methods to the specified Object.
*/
-void QPopupMenuImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQPopupMenuImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -85,11 +85,11 @@ void QPopupMenuImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QPopupMenuImp *meth = new QPopupMenuImp( exec, methods[idx].id );
+ TQPopupMenuImp *meth = new TQPopupMenuImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -98,61 +98,61 @@ void QPopupMenuImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a TQPopupMenu pointer from an Object.
*/
-TQPopupMenu *QPopupMenuImp::toQPopupMenu( KJS::Object &self )
+TTQPopupMenu *TQPopupMenuImp::toTQPopupMenu( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TQObject *obj = ob->object();
+ TTQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TQPopupMenu *>( obj );
+ return dynamic_cast<TTQPopupMenu *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TQPopupMenu" )
+ if ( op->typeName() != "TTQPopupMenu" )
return 0;
- return op->toNative<TQPopupMenu>();
+ return op->toNative<TTQPopupMenu>();
}
/**
* Select and invoke the correct constructor.
*/
-KJS::Object QPopupMenuImp::construct( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQPopupMenuImp::construct( KJS::ExecState *exec, const KJS::List &args )
{
switch( id ) {
case Constructor_QPopupMenu_1:
- return QPopupMenu_1( exec, args );
+ return TQPopupMenu_1( exec, args );
break;
default:
break;
}
- TQString msg = i18n("QPopupMenuCons has no constructor with id '%1'").arg(id);
+ TTQString msg = i18n("TQPopupMenuCons has no constructor with id '%1'").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Object QPopupMenuImp::QPopupMenu_1( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQPopupMenuImp::TQPopupMenu_1( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter TQWidget *
return KJS::Object();
- TQWidget * arg0; // Dummy
+ TTQWidget * arg0; // Dummy
const char *arg1 = (args.size() >= 2) ? args[1].toString(exec).ascii() : 0;
- // We should now create an instance of the TQPopupMenu object
+ // We should now create an instance of the TTQPopupMenu object
- TQPopupMenu *ret = new TQPopupMenu(
+ TTQPopupMenu *ret = new TTQPopupMenu(
arg0,
arg1 );
@@ -160,9 +160,9 @@ KJS::Object QPopupMenuImp::QPopupMenu_1( KJS::ExecState *exec, const KJS::List &
}
-KJS::Value QPopupMenuImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
+KJS::Value TQPopupMenuImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
- instance = QPopupMenuImp::toQPopupMenu( self );
+ instance = TQPopupMenuImp::toTQPopupMenu( self );
switch( id ) {
@@ -238,15 +238,15 @@ KJS::Value QPopupMenuImp::call( KJS::ExecState *exec, KJS::Object &self, const K
break;
}
- TQString msg = i18n( "QPopupMenuImp has no method with id '%1'" ).arg( id );
+ TTQString msg = i18n( "TQPopupMenuImp has no method with id '%1'" ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Value QPopupMenuImp::popup_3( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::popup_3( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQPoint arg0 = extractQPoint(exec, args, 0);
+ TTQPoint arg0 = extractTQPoint(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -257,7 +257,7 @@ KJS::Value QPopupMenuImp::popup_3( KJS::ExecState *exec, KJS::Object &obj, const
}
-KJS::Value QPopupMenuImp::updateItem_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::updateItem_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -268,7 +268,7 @@ KJS::Value QPopupMenuImp::updateItem_4( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QPopupMenuImp::setCheckable_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::setCheckable_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
bool arg0 = extractBool(exec, args, 0);
@@ -279,7 +279,7 @@ KJS::Value QPopupMenuImp::setCheckable_5( KJS::ExecState *exec, KJS::Object &obj
}
-KJS::Value QPopupMenuImp::isCheckable_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::isCheckable_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
bool ret;
@@ -288,10 +288,10 @@ KJS::Value QPopupMenuImp::isCheckable_6( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QPopupMenuImp::setFont_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::setFont_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQFont arg0 = extractQFont(exec, args, 0);
+ TTQFont arg0 = extractTQFont(exec, args, 0);
instance->setFont(
arg0 );
@@ -299,7 +299,7 @@ KJS::Value QPopupMenuImp::setFont_7( KJS::ExecState *exec, KJS::Object &obj, con
}
-KJS::Value QPopupMenuImp::show_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::show_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->show( );
@@ -307,7 +307,7 @@ KJS::Value QPopupMenuImp::show_8( KJS::ExecState *exec, KJS::Object &obj, const
}
-KJS::Value QPopupMenuImp::hide_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::hide_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->hide( );
@@ -315,7 +315,7 @@ KJS::Value QPopupMenuImp::hide_9( KJS::ExecState *exec, KJS::Object &obj, const
}
-KJS::Value QPopupMenuImp::exec_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::exec_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -324,10 +324,10 @@ KJS::Value QPopupMenuImp::exec_10( KJS::ExecState *exec, KJS::Object &obj, const
}
-KJS::Value QPopupMenuImp::exec_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::exec_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQPoint arg0 = extractQPoint(exec, args, 0);
+ TTQPoint arg0 = extractTQPoint(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -339,7 +339,7 @@ KJS::Value QPopupMenuImp::exec_11( KJS::ExecState *exec, KJS::Object &obj, const
}
-KJS::Value QPopupMenuImp::setActiveItem_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::setActiveItem_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -350,16 +350,16 @@ KJS::Value QPopupMenuImp::setActiveItem_12( KJS::ExecState *exec, KJS::Object &o
}
-KJS::Value QPopupMenuImp::sizeHint_13( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::sizeHint_13( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQSize ret;
+ TTQSize ret;
ret = instance->sizeHint( );
return convertToValue( exec, ret );
}
-KJS::Value QPopupMenuImp::idAt_14( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::idAt_14( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -371,10 +371,10 @@ KJS::Value QPopupMenuImp::idAt_14( KJS::ExecState *exec, KJS::Object &obj, const
}
-KJS::Value QPopupMenuImp::idAt_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::idAt_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQPoint arg0 = extractQPoint(exec, args, 0);
+ TTQPoint arg0 = extractTQPoint(exec, args, 0);
int ret;
ret = instance->idAt(
@@ -383,7 +383,7 @@ KJS::Value QPopupMenuImp::idAt_15( KJS::ExecState *exec, KJS::Object &obj, const
}
-KJS::Value QPopupMenuImp::customWhatsThis_16( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::customWhatsThis_16( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
bool ret;
@@ -392,7 +392,7 @@ KJS::Value QPopupMenuImp::customWhatsThis_16( KJS::ExecState *exec, KJS::Object
}
-KJS::Value QPopupMenuImp::insertTearOffHandle_17( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::insertTearOffHandle_17( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -407,7 +407,7 @@ KJS::Value QPopupMenuImp::insertTearOffHandle_17( KJS::ExecState *exec, KJS::Obj
}
-KJS::Value QPopupMenuImp::activateItemAt_18( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::activateItemAt_18( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -418,11 +418,11 @@ KJS::Value QPopupMenuImp::activateItemAt_18( KJS::ExecState *exec, KJS::Object &
}
-KJS::Value QPopupMenuImp::itemGeometry_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQPopupMenuImp::itemGeometry_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
- TQRect ret;
+ TTQRect ret;
ret = instance->itemGeometry(
arg0 );
@@ -98,61 +98,61 @@ void QPopupMenuImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TQPopupMenu pointer from an Object.
+ * Extract a TTQPopupMenu pointer from an Object.
*/
@@ -98,61 +98,61 @@ void QPopupMenuImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
- // Unsupported parameter TQWidget *
+ // Unsupported parameter TTQWidget *
return KJS::Object();